@@ -6,26 +6,22 @@ import asyncio
 import logging
 
 from pyamplipi.amplipi import AmpliPi
-from pyamplipi.models import ZoneUpdate, ZoneUpdateWithId
+from pyamplipi.models import ZoneUpdate, ZoneUpdateWithId, SourceUpdate
 
 _LOGGER = logging.getLogger(__name__)
 
 
 async def get_status():
     amp = AmpliPi(
-        "http://amplipi-dev.local:5000/api",
+        "http://amplipi.local/api",
         10,
     )
     result = await amp.get_status()
-    zone = result.zones.pop()
-    update = await amp.set_zone(zone.id, ZoneUpdate(
-        name=zone.name,
-        source_id=zone.source_id,
-        mute=not zone.mute,
-        vol=zone.vol - 5,
-        disabled=not zone.disabled
-    ))
-    _LOGGER.info(update)
+    source = result.sources[0]
+
+    await amp.previous_stream(source.input.split('=')[1])
+
+    _LOGGER.info(source)
     await amp.close()
 
 
